mailr11524 - /1.3/generic_fns/pymol_control.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on August 17, 2010 - 16:55:
Author: bugman
Date: Tue Aug 17 16:55:48 2010
New Revision: 11524

URL: http://svn.gna.org/viewcvs/relax?rev=11524&view=rev
Log:
Modified the pymol.cone_pdb() user function to handle x, y, and z-axes.


Modified:
    1.3/generic_fns/pymol_control.py

Modified: 1.3/generic_fns/pymol_control.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/generic_fns/pymol_control.py?rev=11524&r1=11523&r2=11524&view=diff
==============================================================================
--- 1.3/generic_fns/pymol_control.py (original)
+++ 1.3/generic_fns/pymol_control.py Tue Aug 17 16:55:48 2010
@@ -233,11 +233,11 @@
     pymol_obj.exec_cmd("load " + file)
 
 
-    # The cone axis.
+    # The cone axes.
     ################
 
-    # Select the AVE, AXE, and SIM residues.
-    pymol_obj.exec_cmd("select (resn AVE,AXE,SIM)")
+    # Select the AVE, XAX, YAX, ZAX, and SIM residues.
+    pymol_obj.exec_cmd("select (resn AVE,XAX,YAX,ZAX,SIM)")
 
     # Show the vector as a stick.
     pymol_obj.exec_cmd("show stick, 'sele'")
@@ -246,7 +246,7 @@
     pymol_obj.exec_cmd("color cyan, 'sele'")
 
     # Select the atom used for labelling.
-    pymol_obj.exec_cmd("select (resn AVE,AXE,SIM and symbol N)")
+    pymol_obj.exec_cmd("select (resn AVE,XAX,YAX,ZAX,SIM and symbol N)")
 
     # Hide the atom.
     pymol_obj.exec_cmd("hide ('sele')")




Related Messages


Powered by MHonArc, Updated Tue Aug 17 17:40:02 2010